==> qtwebengine-everywhere-opensource-src-6.2.5.zip: qtwebengine-everywhere-src-6.2.5/src/3rdparty/chromium/components/autofill/core/browser/payments/test_credit_card_fido_authenticator.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_AUTOFILL_CORE_BROWSER_PAYMENTS_TEST_CREDIT_CARD_FIDO_AUTHENTICATOR_H_
#define COMPONENTS_AUTOFILL_CORE_BROWSER_PAYMENTS_TEST_CREDIT_CARD_FIDO_AUTHENTICATOR_H_

#include <memory>
#include <string>
#include <vector>

#include "components/autofill/core/browser/autofill_client.h"
#include "components/autofill/core/browser/autofill_driver.h"
#include "components/autofill/core/browser/data_model/credit_card.h"
#include "components/autofill/core/browser/payments/credit_card_fido_authenticator.h"
#include "components/autofill/core/browser/payments/payments_client.h"

namespace autofill {

// Test class for CreditCardFIDOAuthenticator.
class TestCreditCardFIDOAuthenticator : public CreditCardFIDOAuthenticator {
 public:
  explicit TestCreditCardFIDOAuthenticator(AutofillDriver* driver,
                                           AutofillClient* client);
  ~TestCreditCardFIDOAuthenticator() override;

  // CreditCardFIDOAuthenticator:
  void GetAssertion(
      PublicKeyCredentialRequestOptionsPtr request_options) override;
  void MakeCredential(
      PublicKeyCredentialCreationOptionsPtr creation_options) override;
  void OptOut() override;

  // Invokes fido_authenticator->OnDidGetAssertion().
  static void GetAssertion(CreditCardFIDOAuthenticator* fido_authenticator,
                           bool did_succeed);

  // Invokes fido_authenticator->OnDidMakeCredential().
  static void MakeCredential(CreditCardFIDOAuthenticator* fido_authenticator,
                             bool did_succeed);

  // Getter methods to query Request Options.
  std::vector<uint8_t> GetCredentialId();
  std::vector<uint8_t> GetChallenge();
  std::string GetRelyingPartyId();

  void SetUserVerifiable(bool is_user_verifiable) {
    is_user_verifiable_ = is_user_verifiable;
  }

  // CreditCardFIDOAuthenticator:
  void IsUserVerifiable(base::OnceCallback<void(bool)> callback) override;

  bool IsOptOutCalled() { return opt_out_called_; }

 private:
  friend class BrowserAutofillManagerTest;
  friend class CreditCardAccessManagerTest;

  PublicKeyCredentialRequestOptionsPtr request_options_;
  PublicKeyCredentialCreationOptionsPtr creation_options_;
  bool is_user_verifiable_ = false;
  bool opt_out_called_ = false;

  DISALLOW_COPY_AND_ASSIGN(TestCreditCardFIDOAuthenticator);
};

}  // namespace autofill

#endif  // COMPONENTS_AUTOFILL_CORE_BROWSER_PAYMENTS_TEST_CREDIT_CARD_FIDO_AUTHENTICATOR_H_

==> qtwebengine-everywhere-opensource-src-6.5.4.zip: qtwebengine-everywhere-src-6.5.4/src/3rdparty/chromium/components/autofill/core/browser/payments/test_credit_card_fido_authenticator.h <==
// Copyright 2019 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_AUTOFILL_CORE_BROWSER_PAYMENTS_TEST_CREDIT_CARD_FIDO_AUTHENTICATOR_H_
#define COMPONENTS_AUTOFILL_CORE_BROWSER_PAYMENTS_TEST_CREDIT_CARD_FIDO_AUTHENTICATOR_H_

#include <memory>
#include <string>
#include <vector>

#include "components/autofill/core/browser/autofill_client.h"
#include "components/autofill/core/browser/autofill_driver.h"
#include "components/autofill/core/browser/data_model/credit_card.h"
#include "components/autofill/core/browser/payments/credit_card_fido_authenticator.h"
#include "components/autofill/core/browser/payments/payments_client.h"

namespace autofill {

// Test class for CreditCardFIDOAuthenticator.
class TestCreditCardFIDOAuthenticator : public CreditCardFIDOAuthenticator {
 public:
  explicit TestCreditCardFIDOAuthenticator(AutofillDriver* driver,
                                           AutofillClient* client);

  TestCreditCardFIDOAuthenticator(const TestCreditCardFIDOAuthenticator&) =
      delete;
  TestCreditCardFIDOAuthenticator& operator=(
      const TestCreditCardFIDOAuthenticator&) = delete;

  ~TestCreditCardFIDOAuthenticator() override;

  // CreditCardFIDOAuthenticator:
  void Authenticate(const CreditCard* card,
                    base::WeakPtr<Requester> requester,
                    base::Value request_options,
                    absl::optional<std::string> context_token) override;
  void IsUserVerifiable(base::OnceCallback<void(bool)> callback) override;
  bool IsUserOptedIn() override;
  void GetAssertion(blink::mojom::PublicKeyCredentialRequestOptionsPtr
                        request_options) override;
  void MakeCredential(blink::mojom::PublicKeyCredentialCreationOptionsPtr
                          creation_options) override;
  void OptOut() override;

  // Invokes fido_authenticator->OnDidGetAssertion().
  static void GetAssertion(CreditCardFIDOAuthenticator* fido_authenticator,
                           bool did_succeed);

  // Invokes fido_authenticator->OnDidMakeCredential().
  static void MakeCredential(CreditCardFIDOAuthenticator* fido_authenticator,
                             bool did_succeed);

  // Getter methods to query Request Options.
  std::vector<uint8_t> GetCredentialId();
  std::vector<uint8_t> GetChallenge();
  std::string GetRelyingPartyId();

  void SetUserVerifiable(bool is_user_verifiable) {
    is_user_verifiable_ = is_user_verifiable;
  }

  void set_is_user_opted_in(bool is_user_opted_in) {
    is_user_opted_in_ = is_user_opted_in;
  }

  bool IsOptOutCalled() { return opt_out_called_; }
  bool authenticate_invoked() { return authenticate_invoked_; }
  const CreditCard& card() { return card_; }
  const absl::optional<std::string>& context_token() { return context_token_; }

  // Resets all the testing related states.
  void Reset();

 private:
  friend class BrowserAutofillManagerTest;
  friend class CreditCardAccessManagerTest;

  blink::mojom::PublicKeyCredentialRequestOptionsPtr request_options_;
  blink::mojom::PublicKeyCredentialCreationOptionsPtr creation_options_;
  bool is_user_verifiable_ = false;
  absl::optional<bool> is_user_opted_in_;
  bool opt_out_called_ = false;
  bool authenticate_invoked_ = false;
  CreditCard card_;
  absl::optional<std::string> context_token_;
};

}  // namespace autofill

#endif  // COMPONENTS_AUTOFILL_CORE_BROWSER_PAYMENTS_TEST_CREDIT_CARD_FIDO_AUTHENTICATOR_H_
